aboutsummaryrefslogtreecommitdiffstats
path: root/Argcfile.sh
diff options
context:
space:
mode:
Diffstat (limited to 'Argcfile.sh')
-rw-r--r--Argcfile.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/Argcfile.sh b/Argcfile.sh
index 0a1ad85..ad926c6 100644
--- a/Argcfile.sh
+++ b/Argcfile.sh
@@ -549,8 +549,8 @@ link-code-interpreter() {
_link_tool $1 code_interpreter
}
-# @cmd Install this repo to aichat functions_dir
-install() {
+# @cmd Link this repo to aichat functions_dir
+link-to-aichat() {
functions_dir="$(aichat --info | grep -w functions_dir | awk '{$1=""; print substr($0,2)}')"
if [[ -z "$functions_dir" ]]; then
_die "error: your aichat version don't support function calling"